Learn R Programming

SpaDES.addins (version 0.1.4)

SpaDES.addins-package: The SpaDES.addins package

Description

Provides 'RStudio' addins for 'SpaDES' packages and 'SpaDES' module development.

Arguments

<code>SpaDES</code> module development

RStudio addins:

  • copy an existing SpaDES module

  • create a new SpaDES module

  • clear recent simulation cache entries

helper functions:

  • none yet

Author

Maintainer: Alex M Chubaty achubaty@for-cast.ca (ORCID)

Other contributors:

  • Her Majesty the Queen in Right of Canada, as represented by the Minister of Natural Resources Canada [copyright holder]

Details

SpaDES logo

See Also