powered by
SpaDES.addins
Provides 'RStudio' addins for 'SpaDES' packages and 'SpaDES' module development.
RStudio addins:
copy an existing SpaDES module
SpaDES
create a new SpaDES module
clear recent simulation cache entries
helper functions:
none yet
Maintainer: Alex M Chubaty achubaty@for-cast.ca (ORCID)
Other contributors:
Her Majesty the Queen in Right of Canada, as represented by the Minister of Natural Resources Canada [copyright holder]
Useful links:
https://spades-addins.predictiveecology.org/
https://github.com/PredictiveEcology/SpaDES.addins
Report bugs at https://github.com/PredictiveEcology/SpaDES.addins/issues